summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/smpppdcs/smpppdsearcher.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/smpppdcs/smpppdsearcher.cpp')
-rw-r--r--kopete/plugins/smpppdcs/smpppdsearcher.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/plugins/smpppdcs/smpppdsearcher.cpp b/kopete/plugins/smpppdcs/smpppdsearcher.cpp
index 4ec77196..cfb103c2 100644
--- a/kopete/plugins/smpppdcs/smpppdsearcher.cpp
+++ b/kopete/plugins/smpppdcs/smpppdsearcher.cpp
@@ -105,8 +105,8 @@ void SMPPPDSearcher::slotStdoutReceivedNetstat(KProcess * /* proc */, char * buf
/*!
\fn SMPPPDSearcher::scan() const
*/
-bool SMPPPDSearcher::scan(const TQString& ip, const TQString& tqmask) {
- kdDebug(14312) << k_funcinfo << "Scanning " << ip << "/" << tqmask << "..." << endl;
+bool SMPPPDSearcher::scan(const TQString& ip, const TQString& mask) {
+ kdDebug(14312) << k_funcinfo << "Scanning " << ip << "/" << mask << "..." << endl;
SMPPPD::Client client;
@@ -123,7 +123,7 @@ bool SMPPPDSearcher::scan(const TQString& ip, const TQString& tqmask) {
uint min_range = 0;
uint max_range = 255;
// calculate ip range (only last tqmask entry)
TQRegExp lastRex("([0-9]{1,3})\\.([0-9]{1,3})\\.([0-9]{1,3})\\.([0-9]{1,3})");
if(lastRex.exactMatch(ip)) {
@@ -134,7 +134,7 @@ bool SMPPPDSearcher::scan(const TQString& ip, const TQString& tqmask) {
ipToks.push_back(lastRex.cap(i));
}
- if(lastRex.exactMatch(tqmask)) {
+ if(lastRex.exactMatch(mask)) {
uint lastWordMask = lastRex.cap(4).toUInt();
if(lastWordMask == 0) {
@@ -123,7 +123,7 @@ bool SMPPPDSearcher::scan(const TQString& ip, const TQString& tqmask) {
uint min_range = 0;
uint max_range = 255;
- // calculate ip range (only last tqmask entry)
+ // calculate ip range (only last mask entry)
TQRegExp lastRex("([0-9]{1,3})\\.([0-9]{1,3})\\.([0-9]{1,3})\\.([0-9]{1,3})");
if(lastRex.exactMatch(ip)) {